@@ -1,12 +1,21 @@
 
+# if egress: distance increasing, from surface to atmosphere
+# if ingress: distance decreasing, from atmosphere to surface
+
+from pudb import set_trace as bp  # noqa:F401
+
+import radiocc
+
+
 def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Surface,EPHE_DIR):
-    import spiceypy
-    import numpy as np
     import os
+
     import matplotlib
-    from PIL import Image
     import matplotlib.pyplot as plt
+    import numpy as np
+    import spiceypy
     from mpl_toolkits.mplot3d import Axes3D
+    from PIL import Image
     
     ang = np.zeros(len(epoch))
     utc = []
@@ -43,6 +52,18 @@ def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Sur
        # Convert time to et     
         et = epoch[index]
         #et = spiceypy.spiceypy.utc2et(epoch[index])
+
+        
+        #returns the position of a target body relative  to an observing body     
+        [pos , ltime] = spiceypy.spiceypy.spkpos( 'Sun', et,frame, abcorr, sc )
+        
+        Dist_sun_MVN =np.linalg.norm(pos)
+            
+        
+        #returns the position of a target body relative  to an observing body
+        [pos , ltime] = spiceypy.spiceypy.spkpos( 'Earth', et,frame, abcorr, sc )
+
+        Dist_MVN_earth=np.linalg.norm(pos)
        
        #Compute the Ls (Solar longitude)
         MARS_LS[index] = spiceypy.spiceypy.lspcn(planet , et, 'none' )*spiceypy.spiceypy.dpr()
@@ -294,7 +315,8 @@ def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Sur
       #ang is of the order of 0.01 or 179.9)
         ang[index] = spiceypy.spiceypy.vsep (v_mnp_sp[index], v_mnp_earth) * spiceypy.spiceypy.dpr()
         
-                
+    print(f"check sphere {pnear} {longitude * 180/np.pi} {latitude * 180/np.pi} {solar[stop_index]}")
+    
     ################### FICHIER INFO_MVN......
                 
     FILE_OUT = 'INFO_'+DATA_ID+'.txt'
@@ -302,7 +324,14 @@ def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Sur
     
     
     output.append("Angular separation between MNP-sp and MNP-sun: %s" %(ang[stop_index]))
+    
     output.append('UTC                       : %s' % utc[stop_index])
+
+    #output.append('Epoch          : %s' %epoch)
+    
+    output.append('MAVEN Sun Distance : %f' %Dist_sun_MVN)
+    
+    output.append('MAVEN EARTH Distance : %f'   %Dist_MVN_earth)
      
     output.append( 'Emission angle       [deg]: %f' %emissn[stop_index])
     
@@ -427,7 +456,12 @@ def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Sur
     
 
     """
-    return distance
+    if distance[1] - distance[0] > 0:
+        DATA_TYPE = radiocc.model.RadioDataType.EGRESS
+    else:
+        DATA_TYPE = radiocc.model.RadioDataType.INGRESS
+
+    return distance, DATA_TYPE
 
  #Profile file name                                  :  "M65RSR0L04_AIX_041391512_05.TAB"
  #Start time                                   [GRT] :  2004-05-18T15:26:42.558
@@ -459,4 +493,4 @@ def occultation_info(planet,ground,epoch,frame,sc,DATA_ID,DATA_DIR,Threshold_Sur
 # Solar Zenith Angle (lowest sample)           [deg] :      69.88
 # Sun-Earth-S/C-Angle (lowest sample)          [deg] :      39.15
 # G/S Elevation Angle (lowest sample)          [deg] :      73.92']
-   
\ No newline at end of file
+   
